==> incendium_stubs-2022.9.2.tar.gz: incendium_stubs-2022.9.2/README.md <==
# incendium-stubs

<!--- Badges --->
![GitHub last commit (stubs)](https://img.shields.io/github/last-commit/thecesrom/incendium-stubs/main)
[![GitHub contributors](https://img.shields.io/github/contributors/thecesrom/stubs)](https://github.com/thecesrom/incendium-stubs/graphs/contributors)
[![Downloads](https://pepy.tech/badge/incendium-stubs)](https://pepy.tech/project/incendium-stubs)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/thecesrom/incendium-stubs/main.svg)](https://results.pre-commit.ci/latest/github/thecesrom/incendium-stubs/main)
[![Join us on GitHub discussions](https://img.shields.io/badge/github-discussions-informational)](https://github.com/thecesrom/incendium/discussions)

This package contains a collection of [stubs](https://www.python.org/dev/peps/pep-484/) for [`thecesrom/incendium`](https://github.com/thecesrom/incendium). These files were generated using `mypy`'s [`stubgen`](https://mypy.readthedocs.io/en/stable/stubgen.html).

Please note that this work is currently in its Beta stage, so don't hesitate to report any issues.

## Installation and usage

To use incendium-stubs, you may install it with `pip`. It requires Python 3.6+.

```sh
python -m pip install incendium-stubs
```

To run `mypy` against your code, execute the following command passing the source directory (typycally `src`) or a single file:

```sh
mypy src
```

Or

```sh
mypy code.py
```

## Contributing

See [CONTRIBUTING.md](https://github.com/thecesrom/incendium/blob/code/CONTRIBUTING.md#contributing-to-incendium).

## Discussions

Feel free to post your questions and/or ideas at [Discussions](https://github.com/thecesrom/icendium/discussions).

## Contributors

Thanks to everyone who has contributed to this project.

Up-to-date list of contributors can be found [here](https://github.com/thecesrom/incendium-stubs/graphs/contributors).

## License

See the [LICENSE](https://github.com/thecesrom/incendium-stubs/blob/HEAD/LICENSE).

## Code of conduct

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/).

==> incendium_stubs-2023.1.0.tar.gz: incendium_stubs-2023.1.0/README.md <==
# incendium-stubs

<!--- Badges --->
![GitHub last commit (stubs)](https://img.shields.io/github/last-commit/thecesrom/incendium-stubs/main)
[![GitHub contributors](https://img.shields.io/github/contributors/thecesrom/incendium-stubs)](https://github.com/thecesrom/incendium-stubs/graphs/contributors)
[![Downloads](https://pepy.tech/badge/incendium-stubs)](https://pepy.tech/project/incendium-stubs)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/thecesrom/incendium-stubs/main.svg)](https://results.pre-commit.ci/latest/github/thecesrom/incendium-stubs/main)
[![Join us on GitHub discussions](https://img.shields.io/badge/github-discussions-informational)](https://github.com/thecesrom/incendium/discussions)

This package contains a collection of [stubs](https://www.python.org/dev/peps/pep-484/) for [`thecesrom/incendium`](https://github.com/thecesrom/incendium). These files were generated using `mypy`'s [`stubgen`](https://mypy.readthedocs.io/en/stable/stubgen.html).

## Installation and usage

To use `incendium-stubs`, you may install it with `pip`. It requires Python 3.6 through 3.10.

```sh
python -m pip install incendium-stubs
```

To run `mypy` against your code, execute the following command passing the source directory (typycally `src`) or a single file:

```sh
mypy src
```

Or

```sh
mypy code.py
```

## Contributing

See [CONTRIBUTING.md](https://github.com/thecesrom/incendium/blob/code/CONTRIBUTING.md#contributing-to-incendium).

## Discussions

Feel free to post your questions and/or ideas at [Discussions](https://github.com/thecesrom/icendium/discussions).

## Contributors

Thanks to everyone who has contributed to this project.

Up-to-date list of contributors can be found [here](https://github.com/thecesrom/incendium-stubs/graphs/contributors).

## License

See the [LICENSE](https://github.com/thecesrom/incendium-stubs/blob/HEAD/LICENSE).

## Code of conduct

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/).
